@@ -1,6 +1,5 @@
-from xpresso._security.api_key import APIKeyCookie, APIKeyHeader, APIKeyQuery
-from xpresso._security.functions import Security
-from xpresso._security.http import (
+from xpresso.binders._security.api_key import APIKeyCookie, APIKeyHeader, APIKeyQuery
+from xpresso.binders._security.http import (
     HTTPAuthorizationCredentials,
     HTTPBase,
     HTTPBasic,
@@ -8,15 +7,14 @@ from xpresso._security.http import (
     HTTPBearer,
     HTTPDigest,
 )
-from xpresso._security.oauth2 import (
+from xpresso.binders._security.oauth2 import (
     OAuth2,
     OAuth2AuthorizationCodeBearer,
     OAuth2PasswordBearer,
     OAuth2PasswordRequestForm,
     OAuth2PasswordRequestFormStrict,
-    SecurityScopes,
 )
-from xpresso._security.open_id_connect_url import OpenIdConnect
+from xpresso.binders._security.open_id_connect_url import OpenIdConnect
 
 __all__ = (
     "APIKeyCookie",
@@ -33,8 +31,6 @@ __all__ = (
     "OAuth2PasswordBearer",
     "OAuth2PasswordRequestForm",
     "OAuth2PasswordRequestFormStrict",
-    "Security",
-    "SecurityScopes",
     "OpenIdConnect",
     "HTTPBase",
 )
